#!/usr/bin/env python3
# (C) Copyright 2023 European Centre for Medium-Range Weather Forecasts.
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# In applying this licence, ECMWF does not waive the privileges and immunities
# granted to it by virtue of its status as an intergovernmental organisation
# nor does it submit to any jurisdiction.
from __future__ import annotations

from climetlab.decorators import normalize

from climetlab_wekeo_mercator.main import Main

LAYERS = [
    "cmems_obs-sst_bal_phy-subskin_nrt_l4_PT1H-m_202211",  # noqa: E501 North sea/baltic sea sst l4 diurnal sub-skin sea surface temperature analysis (sst bal phy subskin l4 NRT 010 034, cmems obs-sst bal phy-subskin NRT l4 pt1h-m)
]


class sst_bal_phy_subskin_l4_nrt(Main):
    name = "EO:MO:DAT:SST_BAL_PHY_SUBSKIN_L4_NRT_010_034"
    dataset = "EO:MO:DAT:SST_BAL_PHY_SUBSKIN_L4_NRT_010_034"

    string_selects = [
        "variables",
    ]

    @normalize("layer", LAYERS)
    @normalize("area", "bounding-box(list)")
    @normalize(
        "variables",
        [
            "analysed_sst",
            "analysis_error",
            "lat",
            "lon",
            "mask",
            "sea_ice_fraction",
            "time",
        ],
        multiple=True,
    )
    @normalize("start", "date(%Y-%m-%dT%H:%M:%SZ)")
    @normalize("end", "date(%Y-%m-%dT%H:%M:%SZ)")
    def __init__(
        self,
        layer="cmems_obs-sst_bal_phy-subskin_nrt_l4_PT1H-m_202211",
        area=None,
        variables=None,
        start=None,
        end=None,
    ):
        if layer == "cmems_obs-sst_bal_phy-subskin_nrt_l4_PT1H-m_202211":
            if start is None:
                start = "2022-05-01T00:00:00Z"

            if end is None:
                end = "2023-09-25T00:00:00Z"

        super().__init__(
            layer=layer,
            area=area,
            variables=variables,
            start=start,
            end=end,
        )
